@@ -1,6 +1,4 @@
 /*
-    This file is part of the Kasten Framework, made within the KDE community.
-
     SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
@@ -16,6 +14,7 @@
 #include <QThread>
 // Std
 #include <memory>
+#include <utility>
 
 namespace Kasten {
 
