@@ -1,6 +1,4 @@
 /*
-    This file is part of the Okteta Gui library, made within the KDE community.
-
     SPDX-FileCopyrightText: 2008-2010 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
@@ -285,7 +283,7 @@ public:
 
     /** sets the number of bytes per line, switching the resize style to Okteta::FixedLayoutStyle */
     void setNoOfBytesPerLine(int noOfBytesPerLine);
-    /** sets absolut offset of the data */
+    /** sets absolute offset of the data */
     void setStartOffset(Address startOffset);
     /** sets offset of the char in the upper left corner */
     void setFirstLineOffset(Address firstLineOffset);
@@ -316,10 +314,10 @@ public:
 
 public:
     [[nodiscard]]
-    virtual bool canInsertBytesFromMimeData(const QMimeData* data) const;
+    virtual bool canInsertBytesFromMimeData(const QMimeData* mimeData) const;
 
 public: // modification access
-    virtual void insertBytesFromMimeData(const QMimeData* data);
+    virtual void insertBytesFromMimeData(const QMimeData* mimeData);
     /** removes the selected data, takes care of the cursor */
     void removeSelectedBytes();
     /** inserts */
@@ -401,7 +399,7 @@ public: // logic value service
 Q_SIGNALS:
     /** Index of the byte that was clicked */
     void clicked(Okteta::Address index);
-    /** Index of the byte that was double clicked */
+    /** Index of the byte that was double-clicked */
     void doubleClicked(Okteta::Address index);
 
     void cursorPositionChanged(Okteta::Address index);
